@@ -5,9 +5,13 @@ you can actually reach the app's views (provided it has any views, of course).
 
 """
 from django.conf.urls.defaults import include, patterns, url
+from django.contrib import admin
+
+
+admin.autodiscover()
 
 
 urlpatterns = patterns('',
+    url(r'^admin/', include(admin.site.urls)),
     url(r'^s/', include('tinylinks.urls')),
-    url(r'^jasmine/', include('django_jasmine.urls')),
 )
